# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`openssl`](#openssl): Manage X.509 certificates, keys and Diffie-Hellman parameter files

**Defined types**

* [`openssl::cert`](#opensslcert): Manage an X.509 certificate file in PEM format
* [`openssl::dhparam`](#openssldhparam): Manage Diffie-Hellman parameter files.
* [`openssl::key`](#opensslkey): Manage an X.509 key file in PEM format

## Classes

### openssl

Manage X.509 certificates, keys and Diffie-Hellman parameter files

#### Examples

##### Declaring the class

```puppet

class { 'openssl':
  cert_source_directory => '/etc/puppetlabs/code/private/certs',
}
```

##### Declaring the class and deploy a CA certificate

```puppet

class { 'openssl':
  cert_source_directory => '/etc/puppetlabs/code/private/certs',
  root_ca_certs         => [ 'ACME-Root-CA' ],
}
```

#### Parameters

The following parameters are available in the `openssl` class.

##### `cert_source_directory`

Data type: `Stdlib::Absolutepath`

The directory on the Puppetmaster where all certificate and key files are
kept. Every certificate or key file will be read from this directory and
then deployed on the client. This directory is accessed using the `file`
function and therefore does not need to be part of the Puppet directory
structure. But obviously the directory and the files must be readable by
the Puppet user. This parameter is mandatory and has no default.

##### `default_key_dir`

Data type: `Stdlib::Absolutepath`

The default directory where a key file is deployed. This is operating
system specific. On Debian this is `/etc/ssl/private` and on RedHat this
is `/etc/pki/tls/private`.

##### `default_cert_dir`

Data type: `Stdlib::Absolutepath`

The default directory where a certificate file is deployed. This is
operating system specific. On Debian this is `/etc/ssl/certs` and on
RedHat this is `/etc/pki/tls/certs`.

##### `package_name`

Data type: `String`

The name of the openssl package to install.

##### `package_ensure`

Data type: `String`

The desired package state.

##### `root_group`

Data type: `String`

The group used for deployed files. This is operating system specific. On
Linux this is normally `root`. On FreeBSD this is `wheel`.

##### `ca_certs`

Data type: `Array[String]`

An array of CA certificates that are installed by default.

## Defined types

### openssl::cert

Manage an X.509 certificate file in PEM format

#### Examples

##### Install the 'imap' cert in the default location

```puppet

openssl::cert { 'imap': }
```

##### Install the 'postgresql' cert using application specific defaults

```puppet

openssl::cert { 'postgresql':
  cert     => $::hostname,
  owner    => 'root',
  group    => 'postgres',
  mode     => '0444',
  cert_dir => '/etc/postgresql',
  source   => $::hostname,
}
```

#### Parameters

The following parameters are available in the `openssl::cert` defined type.

##### `ensure`

Data type: `Enum['present','absent']`

The state of the resource. Can be `present` or `absent`.

Default value: 'present'

##### `cert`

Data type: `String`

The basename of the file where the certificate will be stored on the
client. The full filename will be created using the three components
`cert_dir`, `cert` and `extension`.

Default value: $name

##### `source`

Data type: `String`

The basename of the file where the certificate is stored on the server.
The full filename will be created using the three parameters
`cert_source_directory` (see the base class `openssl`), `source` and
`source_extension`.

Default value: $name

##### `cert_chain`

Data type: `Array[String]`

An array of certificate names that are should be added to the certificate
file. This allows the generation of certificate chains to provide a full
verification path for the certificate if intermediate CAs are used. The
chain is included in the generated certificate file. The certificates
must be available in `cert_source_directory` on the server just like the
ordinary certificate.

Default value: []

##### `extension`

Data type: `String`

The file extension used for files created on the client.

Default value: 'crt'

##### `source_extension`

Data type: `String`

The file extension used for files read on the server.

Default value: 'crt'

##### `makehash`

Data type: `Boolean`

A boolean value that determines if a symbolic link using the certificate
hash value should be generated on the client.

Default value: `false`

##### `mode`

Data type: `Stdlib::Filemode`

The file mode used for the resource.

Default value: '0444'

##### `owner`

Data type: `String`

The file owner used for the resource.

Default value: 'root'

##### `group`

Data type: `Optional[String]`

The file group used for the resource.

Default value: `undef`

##### `cert_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The destination directory on the client where the certificate will be
stored.

Default value: `undef`

### openssl::dhparam

Manage Diffie-Hellman parameter files.

#### Examples

##### Create a parameter file using default parameters

```puppet

openssl::dhparam { '/etc/ssl/dhparam.pem': }
```

##### Create a parameter file using 4096 bits

```puppet

openssl::dhparam { '/etc/ssl/dhparam.pem':
  bits => '4096',
}
```

##### Create a parameter file using non-default permissions

```puppet

openssl::dhparam { '/etc/ssl/dhparam.pem':
  owner => 'www-data',
  group => 'www-data',
  mode  => '0640',
}
```

#### Parameters

The following parameters are available in the `openssl::dhparam` defined type.

##### `ensure`

Data type: `Enum['present','absent']`

The state of the resource. Can be `present` or `absent`.

Default value: 'present'

##### `file`

Data type: `Stdlib::Absolutepath`

The file name where the DH parameters are stored on the node. Must be an
absolute path.

Default value: $name

##### `bits`

Data type: `Enum['2048','4096','8192']`

The number of bits to generate. Must be one of the strings `2048`, `4096`
or `8192`.

Default value: '2048'

##### `generator`

Data type: `Enum['2','5']`

The generator to use. Must be the string `2` or `5`. Check the openssl
documentation for details about this parameter.

Default value: '2'

##### `mode`

Data type: `Stdlib::Filemode`

The file mode used for the resource.

Default value: '0644'

##### `owner`

Data type: `String`

The file owner used for the resource.

Default value: 'root'

##### `group`

Data type: `Optional[String]`

The file group used for the resource.

Default value: `undef`

### openssl::key

Manage an X.509 key file in PEM format

#### Examples

##### Install the 'imap' key in the default location

```puppet

openssl::key { 'imap': }
```

##### Install the 'postgresql' key using application specific defaults

```puppet

openssl::key { 'postgresql':
  key     => $::hostname,
  owner   => 'root',
  group   => 'postgres',
  mode    => '0440',
  key_dir => '/etc/postgresql',
  source  => $::hostname,
}
```

#### Parameters

The following parameters are available in the `openssl::key` defined type.

##### `ensure`

Data type: `Enum['present','absent']`

The state of the resource. Can be `present` or `absent`.

Default value: 'present'

##### `key`

Data type: `String`

The basename of the file where the key will be stored on the client. The
full filename will be created using the three components `key_dir`, `key`
and `extension`.

Default value: $name

##### `source`

Data type: `String`

The basename of the file where the key is stored on the server. The full
filename will be created using the three parameters
`cert_source_directory` (see the base class `openssl`), `source` and
`source_extension`.

Default value: $name

##### `extension`

Data type: `String`

The file extension used for files created on the client.

Default value: 'key'

##### `source_extension`

Data type: `String`

The file extension used for files read on the server.

Default value: 'key'

##### `mode`

Data type: `Stdlib::Filemode`

The file mode used for the resource.

Default value: '0400'

##### `owner`

Data type: `String`

The file owner used for the resource.

Default value: 'root'

##### `group`

Data type: `Optional[String]`

The file group used for the resource.

Default value: `undef`

##### `key_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The destination directory on the client where the key will be stored.

Default value: `undef`

